plottery_cli 0.7.3

Command line interface of Plottery, a creative coding framework for generative vector graphics and pen plotting.
plottery_cli-0.7.3 is not a library.

Plottery CLI

The cli is used to create and manage projects.

Create a new sketch:

plottery new new_sketch